==> python-can-4.0.0.tar.gz: python-can-4.0.0/can/io/printer.py <==
"""
This Listener simply prints to stdout / the terminal or a file.
"""

import logging

from typing import Optional, TextIO, Union

from ..message import Message
from .generic import MessageWriter
from ..typechecking import StringPathLike

log = logging.getLogger("can.io.printer")


class Printer(MessageWriter):
    """
    The Printer class is a subclass of :class:`~can.Listener` which simply prints
    any messages it receives to the terminal (stdout). A message is turned into a
    string using :meth:`~can.Message.__str__`.

    :attr write_to_file: `True` if this instance prints to a file instead of
                         standard out
    """

    file: Optional[TextIO]

    def __init__(
        self, file: Optional[Union[StringPathLike, TextIO]] = None, append: bool = False
    ) -> None:
        """
        :param file: An optional path-like object or a file-like object to "print"
                     to instead of writing to standard out (stdout).
                     If this is a file-like object, is has to be opened in text
                     write mode, not binary write mode.
        :param append: If set to `True` messages, are appended to the file,
                       else the file is truncated
        """
        mode = "a" if append else "w"
        super().__init__(file, mode=mode)

    def on_message_received(self, msg: Message) -> None:
        if self.file is not None:
            self.file.write(str(msg) + "\n")
        else:
            print(msg)

==> python-can_4.1.0.orig.tar.gz: python-can-4.1.0/can/io/printer.py <==
"""
This Listener simply prints to stdout / the terminal or a file.
"""

import logging

from typing import Optional, TextIO, Union, Any, cast

from ..message import Message
from .generic import MessageWriter
from ..typechecking import StringPathLike

log = logging.getLogger("can.io.printer")


class Printer(MessageWriter):
    """
    The Printer class is a subclass of :class:`~can.Listener` which simply prints
    any messages it receives to the terminal (stdout). A message is turned into a
    string using :meth:`~can.Message.__str__`.

    :attr write_to_file: `True` if this instance prints to a file instead of
                         standard out
    """

    file: Optional[TextIO]

    def __init__(
        self,
        file: Optional[Union[StringPathLike, TextIO]] = None,
        append: bool = False,
        *args: Any,
        **kwargs: Any
    ) -> None:
        """
        :param file: An optional path-like object or a file-like object to "print"
                     to instead of writing to standard out (stdout).
                     If this is a file-like object, is has to be opened in text
                     write mode, not binary write mode.
        :param append: If set to `True` messages, are appended to the file,
                       else the file is truncated
        """
        self.write_to_file = file is not None
        mode = "a" if append else "w"
        super().__init__(file, mode=mode)

    def on_message_received(self, msg: Message) -> None:
        if self.write_to_file:
            cast(TextIO, self.file).write(str(msg) + "\n")
        else:
            print(msg)

    def file_size(self) -> int:
        """Return an estimate of the current file size in bytes."""
        if self.file is not None:
            return self.file.tell()
        return 0
